window.Gleam.initSearch([{"doc":"bigdecimal","title":"bigdecimal","content":"# :b: bigdecimal\n\n[![Package Version](https://img.shields.io/hexpm/v/bigdecimal)](https://hex.pm/packages/bigdecimal)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bigdecimal/)\n![Erlang Target](https://img.shields.io/badge/target-erlang-A90433)\n![JavaScript Target](https://img.shields.io/badge/target-javascript-F7E02A)\n\nA library for [arbitrary precision decimal arithmetic](https://en.wikipedia.org/wiki/Arbitrary-precision_arithmetic) in Gleam.\n\nThis library builds on the excellent [bigi](https://hex.pm/packages/bigi) library, which is used\nto represent the unscaled value of `BigDecimal`s.\nA `BigDecimal` consists of an arbitrary precision integer unscaled value of type `bigi.Bigint`\nand an integer scale of built-in type `Int` (arbitrary precision on the Erlang target, bound between\n[Number.MIN_SAFE_INTEGER](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MIN_SAFE_INTEGER)\nand [Number.MAX_SAFE_INTEGER](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER)\non the JavaScript target). If zero or positive, the scale is the number of digits to the right of\nthe decimal point. If negative, the unscaled value of the number is multiplied by ten to the power\nof the negation of the scale. The value of the number represented by the `BigDecimal` is therefore\nunscaled_value × 10&lt;sup&gt;-scale&lt;/sup&gt;.\n\n## Usage\n\n```sh\ngleam add bigdecimal@1\n```\n\n```gleam\nimport bigdecimal\n\npub fn main() {\n  let assert Ok(number) = bigdecimal.from_string(&quot;12.00340&quot;)\n\n  bigdecimal.scale(of: number) // 5\n\n  bigdecimal.unscaled_value(of: number) // 1_200_340\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bigdecimal&gt;.\n\n## Development\n\nThe library supports all targets and runtimes. To do a matrix run of the test suite, run:\n\n```sh\n./scripts/matrix-test.sh\n```\n\n## TODO\n\n### Pre v1\n- [x] absolute value\n- [x] compare\n- [x] add\n- [x] subtract\n- [x] multiply\n- [x] product (list input)\n- [x] sum (list input)\n- [x] signum\n- [x] ulp\n- [x] power\n- [x] rescale/round (with rounding modes)\n- [x] clamp\n- [x] divide\n\n### Post v1\n- [ ] modulo\n- [ ] square root\n- [ ] trim trailing zeros\n- [ ] truncate (to BigInt)\n","url":"index.html"},{"doc":"bigdecimal/rounding","title":"RoundingMode","content":"pub type RoundingMode {\n  Ceiling\n  Floor\n  Down\n  Up\n  HalfDown\n  HalfUp\n  HalfEven\n}\n\nCeiling\n Round towards positive infinity\n\nFloor\n Round towards negative infinity\n\nDown\n Round towards zero\n\nUp\n Round away from zero\n\nHalfDown\n Round towards nearest neighbour. Round down if both neighbours are equidistant.\n\nHalfUp\n Round towards nearest neighbour. Round up if both neighbours are equidistant.\n\nHalfEven\n Round towards nearest neighbour. Round to the even one if both neighbours are equidistant.\n\nSynonyms:\nbigdecimal/rounding.RoundingMode\nbigdecimal/rounding RoundingMode","url":"bigdecimal/rounding.html#RoundingMode"},{"doc":"bigdecimal/rounding","title":"bigdecimal/rounding","content":"","url":"bigdecimal/rounding.html"},{"doc":"bigdecimal","title":"BigDecimal","content":"pub opaque type BigDecimal\n\n\nSynonyms:\nbigdecimal.BigDecimal\nbigdecimal BigDecimal","url":"bigdecimal.html#BigDecimal"},{"doc":"bigdecimal","title":"absolute_value","content":"pub fn absolute_value(of value: BigDecimal) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.absolute_value\nbigdecimal absolute_value","url":"bigdecimal.html#absolute_value"},{"doc":"bigdecimal","title":"add","content":"pub fn add(augend: BigDecimal, addend: BigDecimal) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.add\nbigdecimal add","url":"bigdecimal.html#add"},{"doc":"bigdecimal","title":"clamp","content":"pub fn clamp(\n  value: BigDecimal,\n  min min: BigDecimal,\n  max max: BigDecimal,\n) -&gt; BigDecimal\n N.B. if the input has equal value to either of the extremes\n but different precision, the larger precision will be returned\n\nSynonyms:\nbigdecimal.clamp\nbigdecimal clamp","url":"bigdecimal.html#clamp"},{"doc":"bigdecimal","title":"compare","content":"pub fn compare(this: BigDecimal, with that: BigDecimal) -&gt; Order\n N.B. If scale is different, trailing zeros are ignored.\n\nSynonyms:\nbigdecimal.compare\nbigdecimal compare","url":"bigdecimal.html#compare"},{"doc":"bigdecimal","title":"divide","content":"pub fn divide(\n  dividend: BigDecimal,\n  by divisor: BigDecimal,\n  rounding rounding: RoundingMode,\n) -&gt; BigDecimal\n Divide the dividend by the divisor.\n The result has a preferred scale of `scale(dividend) - scale(divisor)`,\n but might have scale up to `precision(dividend) + ceil(10 * precision(divisor) / 3)`.\n\nSynonyms:\nbigdecimal.divide\nbigdecimal divide","url":"bigdecimal.html#divide"},{"doc":"bigdecimal","title":"from_float","content":"pub fn from_float(value: Float) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.from_float\nbigdecimal from_float","url":"bigdecimal.html#from_float"},{"doc":"bigdecimal","title":"from_string","content":"pub fn from_string(value: String) -&gt; Result(BigDecimal, Nil)\n\nSynonyms:\nbigdecimal.from_string\nbigdecimal from_string","url":"bigdecimal.html#from_string"},{"doc":"bigdecimal","title":"multiply","content":"pub fn multiply(\n  multiplicand: BigDecimal,\n  with multiplier: BigDecimal,\n) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.multiply\nbigdecimal multiply","url":"bigdecimal.html#multiply"},{"doc":"bigdecimal","title":"negate","content":"pub fn negate(value: BigDecimal) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.negate\nbigdecimal negate","url":"bigdecimal.html#negate"},{"doc":"bigdecimal","title":"one","content":"pub fn one() -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.one\nbigdecimal one","url":"bigdecimal.html#one"},{"doc":"bigdecimal","title":"power","content":"pub fn power(\n  value: BigDecimal,\n  exponent: Int,\n) -&gt; Result(BigDecimal, Nil)\n Returns an error if the exponent is negative.\n (Inherited behaviour from `bigi`)\n\nSynonyms:\nbigdecimal.power\nbigdecimal power","url":"bigdecimal.html#power"},{"doc":"bigdecimal","title":"precision","content":"pub fn precision(of value: BigDecimal) -&gt; Int\n The number of digits in the unscaled value.\n\nSynonyms:\nbigdecimal.precision\nbigdecimal precision","url":"bigdecimal.html#precision"},{"doc":"bigdecimal","title":"product","content":"pub fn product(values: List(BigDecimal)) -&gt; BigDecimal\n For an empty list, this will return `one()`.\n\nSynonyms:\nbigdecimal.product\nbigdecimal product","url":"bigdecimal.html#product"},{"doc":"bigdecimal","title":"rescale","content":"pub fn rescale(\n  value: BigDecimal,\n  scale new_scale: Int,\n  rounding rounding: RoundingMode,\n) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.rescale\nbigdecimal rescale","url":"bigdecimal.html#rescale"},{"doc":"bigdecimal","title":"scale","content":"pub fn scale(of value: BigDecimal) -&gt; Int\n\nSynonyms:\nbigdecimal.scale\nbigdecimal scale","url":"bigdecimal.html#scale"},{"doc":"bigdecimal","title":"signum","content":"pub fn signum(of value: BigDecimal) -&gt; Int\n Sign function. Returns +1 if the value is positive,\n -1 if the value is negative, 0 if the value is zero.\n\nSynonyms:\nbigdecimal.signum\nbigdecimal signum","url":"bigdecimal.html#signum"},{"doc":"bigdecimal","title":"subtract","content":"pub fn subtract(\n  minuend: BigDecimal,\n  subtrahend: BigDecimal,\n) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.subtract\nbigdecimal subtract","url":"bigdecimal.html#subtract"},{"doc":"bigdecimal","title":"sum","content":"pub fn sum(values: List(BigDecimal)) -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.sum\nbigdecimal sum","url":"bigdecimal.html#sum"},{"doc":"bigdecimal","title":"ulp","content":"pub fn ulp(of value: BigDecimal) -&gt; BigDecimal\n Returns the unit of least precision of this `BigDecimal`.\n\nSynonyms:\nbigdecimal.ulp\nbigdecimal ulp","url":"bigdecimal.html#ulp"},{"doc":"bigdecimal","title":"unscaled_value","content":"pub fn unscaled_value(of value: BigDecimal) -&gt; BigInt\n\nSynonyms:\nbigdecimal.unscaled_value\nbigdecimal unscaled_value","url":"bigdecimal.html#unscaled_value"},{"doc":"bigdecimal","title":"zero","content":"pub fn zero() -&gt; BigDecimal\n\nSynonyms:\nbigdecimal.zero\nbigdecimal zero","url":"bigdecimal.html#zero"},{"doc":"bigdecimal","title":"bigdecimal","content":"","url":"bigdecimal.html"}]);